import { useConfig } from '@kevisual/use-config/env';
import { useFileStore } from '@kevisual/use-config/file-store';
import { minioResources } from './minio.ts';
export const fileStore = useFileStore('pages');

type ConfigType = {
  api: {
    /**
     * API host address
     */
    host: string;
    path?: string;
    port?: number;
  };
  apiList: {
    path: string;
    /**
     * url或者相对路径
     */
    target: string;
    /**
     * 类型
     */
    type?: 'static' | 'dynamic' | 'minio';
  }[];
  proxy: {
    port?: number;
    /**
     * self domain kevisual.xiongxiao.me
     */
    domain: string;
    /**
     * resources path
     * https://minio.xiongxiao.me/resources
     */
    resources: string;
    /**
     * allow origin xiongxiao.me zxj.im silkyai.cn
     * 允许跨域访问的地址
     */
    allowedOrigin: string[];
  };
  stat: {
    /**
     * 统计网站ID
     */
    websiteId: string;
  };
  redis?: {
    host: string;
    port: number;
    password?: string;
  };
};

// export const config = useConfig();
export const envConfig = useConfig() as any;
export const config: ConfigType = {
  api: {
    host: envConfig.API_HOST,
    path: envConfig.API_PATH,
    port: envConfig.PROXY_PORT,
  },
  apiList: [
    {
      path: '/api',
      target: envConfig.API_HOST,
    },
    {
      path: '/client',
      target: envConfig.API_CLIENT_HOST || 'https://localhost:51015',
    },
  ],
  proxy: {
    port: envConfig.PROXY_PORT,
    domain: envConfig.PROXY_DOMAIN,
    resources: minioResources,
    allowedOrigin: (envConfig.PROXY_ALLOWED_ORIGINS as string)?.split(',') || [],
  },
  redis: {
    host: envConfig.REDIS_HOST,
    port: envConfig.REDIS_PORT,
    password: envConfig.REDIS_PASSWORD,
  },
  stat: {
    websiteId: envConfig.DATA_WEBSITE_ID,
  },
};
