import http from 'http';
import { minioClient } from '../minio.ts';
export type ProxyInfo = {
  path?: string;
  target: string;
  type?: 'static' | 'dynamic' | 'minio';
};
export const minioProxy = async (req: http.IncomingMessage, res: http.ServerResponse, proxyApi: ProxyInfo) => {
  try {
    const requestUrl = new URL(req.url, 'http://localhost');
    const objectPath = requestUrl.pathname;
    const bucketName = proxyApi.target;
    let objectName = objectPath.slice(1);
    if (objectName.startsWith(bucketName)) {
      objectName = objectName.slice(bucketName.length);
    }
    const objectStream = await minioClient.getObject(bucketName, objectName);
    objectStream.pipe(res);
  } catch (error) {
    console.error('Error fetching object from MinIO:', error);
    res.statusCode = 500;
    res.end('Internal Server Error');
  }
};
