import { Redis } from 'ioredis';
import { useContextKey } from '@kevisual/use-config/context';
console.log(process.env.REDIS_HOST);
import { config } from '../config.ts';
const redisConfig = {
  host: config?.redis?.host || 'localhost', // Redis 服务器的主机名或 IP 地址
  port: config?.redis?.port || 6379, // Redis 服务器的端口号
  password: config?.redis?.password, // Redis 的密码 (如果有)
};
const init = () => {
  return new Redis({
    host: 'localhost', // Redis 服务器的主机名或 IP 地址
    port: 6379, // Redis 服务器的端口号
    // password: 'your_password', // Redis 的密码 (如果有)
    db: 0, // 要使用的 Redis 数据库索引 (0-15)
    keyPrefix: '', // key 前缀
    retryStrategy(times) {
      // 连接重试策略
      return Math.min(times * 50, 2000); // 每次重试时延迟增加
    },
    maxRetriesPerRequest: null, // 允许请求重试的次数 (如果需要无限次重试)
    ...redisConfig,
  });
};
// 配置 Redis 连接
export const redis = useContextKey('redis', init);
export const subscriber = redis.duplicate(); // 创建一个订阅者连接

async function ensureKeyspaceNotifications() {
  try {
    // 获取当前的 `notify-keyspace-events` 配置
    const currentConfig = (await redis.config('GET', 'notify-keyspace-events')) as string[];

    // 检查返回的数组长度是否大于1，表示获取成功
    if (currentConfig && currentConfig.length > 1) {
      const currentSetting = currentConfig[1]; // 值在数组的第二个元素
      // 检查当前配置是否包含 "Ex"
      if (!currentSetting.includes('E') || !currentSetting.includes('x')) {
        console.log('Keyspace notifications are not fully enabled. Setting correct value...');
        await redis.config('SET', 'notify-keyspace-events', 'Ex');
        console.log('Keyspace notifications enabled with setting "Ex".');
      } else {
        // console.log('Keyspace notifications are already correctly configured.');
      }
    } else {
      console.error('Failed to get the current notify-keyspace-events setting.');
    }
  } catch (err) {
    console.error('Error while configuring Redis keyspace notifications:', err);
  }
}

// 确保键空间通知被正确设置
ensureKeyspaceNotifications().catch(console.error);
